%%Identification
%%The class identifies itself and the LaTeX version needed
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{info4proy}[2018/03/14 Clase LaTeX de Informe Ejecutivo Cuatrimestral de Proyectos]

%%Preliminary definitions, needed by the options
\newcommand{\headlinecolor}{\normalcolor}
\LoadClass{report}

\RequirePackage{xcolor}
\definecolor{slcolor}{HTML}{882B21}

\RequirePackage[centertags]{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{amsthm}
\RequirePackage[spanish,es-tabla]{babel}

\RequirePackage[utf8]{inputenc}
\RequirePackage{graphicx}
\RequirePackage{color}
%%%incluye paginas o partes de documentos PDF
\RequirePackage{pdfpages}
\RequirePackage{hyperref}
\RequirePackage{titlesec}

\titleclass{\subchapter}{straight}[\chapter] \newcounter{subchapter} \renewcommand{\thesubchapter}{\Alph{subchapter}}

\addto\captionsspanish{\renewcommand{\chaptername}{Informe de Actividades de Proyectos}}
\titleformat{\chapter}[display]{\Large\bfseries\headlinecolor\centering}{\centering\chaptername}{0pt}{}

\titleformat{\subchapter}[hang]{\large\bfseries\headlinecolor\centering}{}{0pt}{}[\titlerule]
\titleformat{\section}[hang]{\Large\sffamily\slshape\headlinecolor}{\thesection.\ }{0pt}{}
\titleformat{\subsection}[hang]{\large\sffamily\slshape\headlinecolor}{\thesubsection.\ }{0pt}{}
\titlespacing{\chapter}{0pt}{-18pt}{0pt}
\titlespacing{\subchapter}{0pt}{-15pt}{9pt}
\titlespacing{\section}{0pt}{1.0ex plus -1ex minus -.2ex}
{1ex plus .2ex}
\titlespacing{\subsection}{0pt}{1.0ex plus -1ex minus -.2ex}
{1ex plus .2ex}

%section numbers
\renewcommand\thesection{\arabic{section}}

%%% Márgenes ---------------------------------
\RequirePackage[letterpaper,top=2cm,bottom=2.25cm,left=2.25cm,right=2cm,asymmetric,headsep=8pt,headheight=1.5cm,footskip=12pt]{geometry}

% % %Actividades
\newcommand{\autores}[1]{\indent\begin{minipage}[t]{0.1\textwidth}{\em Autores:}\end{minipage}
\begin{minipage}[t]{0.86\textwidth}#1\end{minipage}}
\newcommand{\fechas}[1]{\indent\begin{minipage}[t]{0.1\textwidth}{\em Fechas:}\end{minipage}
\begin{minipage}[t]{0.86\textwidth}#1\end{minipage}}
\newcommand{\actividad}[1]{\indent\begin{minipage}[t]{0.1\textwidth}{\em Descripción de actividad realizada:}\end{minipage}
\fbox{\begin{minipage}[t]{0.86\textwidth}#1\end{minipage}}}
\newcommand{\resultado}[1]{\indent\begin{minipage}[t]{0.1\textwidth}{\em Resultado:}\end{minipage}
	\begin{minipage}[t]{0.86\textwidth}#1\end{minipage}}
\newcommand{\respaldo}[1]{\indent\begin{minipage}[t]{0.1\textwidth}{\em Respaldo:}\end{minipage}
\begin{minipage}[t]{0.86\textwidth}#1\end{minipage}}

% % %Encabezado
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\headheight=60pt %para cambiar el tamaño del encabezado
\fancyhead[L] %la "L" indica a la izquierda
{
	\begin{minipage}{0.6cm}
		\includegraphics[width=0.9\textwidth]{escumsapq.png}
	\end{minipage}
	\begin{minipage}{6cm}
\small{\textsf{Universidad Mayor de San Andrés\\
				Facultad de Ciencias Puras y Naturales
		}}
\end{minipage}}

\fancyhead[R] %la "R" indica a la derecha
{\begin{minipage}{6cm}\begin{flushright}
	\small{\textsf{
		Carrera de Matemática\\
		Instituto de Invesigación Matemática}}
		\end{flushright}
\end{minipage}
}

% Redefine the plain page style
\fancypagestyle{plain}{%
	\fancyhf{}%
\fancyhead[L] %la "L" indica a la izquierda
{
	\begin{minipage}{0.6cm}
		\includegraphics[width=0.9\textwidth]{escumsapq.png}
	\end{minipage}
	\begin{minipage}{6cm}
		\small{\textsf{Universidad Mayor de San Andrés\\
				Facultad de Ciencias Puras y Naturales
		}}
\end{minipage}}

\fancyhead[R] %la "R" indica a la derecha
{\begin{minipage}{6cm}\begin{flushright}
			\small{\textsf{
					Carrera de Matemática\\
					Instituto de Invesigación Matemática}}
		\end{flushright}
	\end{minipage}
}	
	\fancyfoot[C]{\thepage}%
	\renewcommand{\headrulewidth}{0.4pt}% Line at the header invisible
	\renewcommand{\footrulewidth}{0.4pt}% Line at the footer visible
}

\fancyfoot{}
%%This parts handles the options passed to the class.
% %\DeclareOption{onecolumn}{\OptionNotUsed}
\DeclareOption{green}{\renewcommand{\headlinecolor}{\color{green}}}
\DeclareOption{red}{\renewcommand{\headlinecolor}{\color{slcolor}}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

%\renewcommand{\section}{%
%    \@startsection
%    {section}{1}{0pt}{-1.5ex plus -1ex minus -.2ex}%
%    {1ex plus .2ex}{\Large\sffamily\slshape\headlinecolor}%
%}

%\renewcommand{\subsection}{%
%    \@startsection
%    {subsection}{1}{0pt}{-1.5ex plus -1ex minus -.2ex}%
%    {1ex plus .2ex}{\large\sffamily\slshape\headlinecolor}%
%}

\renewcommand{\normalsize}{\fontsize{9}{10}\selectfont}

%\setcounter{secnumdepth}{0}

\newcommand{\textoverline}[1]{$\overline{\mbox{#1}}$}